@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import List, Tuple, Callable, Optional
+from typing import Callable
 
 import pytest
 from itertools import product
@@ -40,7 +40,7 @@ TEST_POINTS = {
 }
 
 
-PARAMS: List[Tuple[Callable, Callable, Tuple[str, ...], Optional[str]]] = [
+PARAMS: list[tuple[Callable, Callable, tuple[str, ...], str | None]] = [
     (special.agm, cython_special.agm, ('dd',), None),
     (special.airy, cython_special._airy_pywrap, ('d', 'D'), None),
     (special.airye, cython_special._airye_pywrap, ('d', 'D'), None),
@@ -56,7 +56,9 @@ PARAMS: List[Tuple[Callable, Callable, Tuple[str, ...], Optional[str]]] = [
     (special.besselpoly, cython_special.besselpoly, ('ddd',), None),
     (special.beta, cython_special.beta, ('dd',), None),
     (special.betainc, cython_special.betainc, ('ddd',), None),
+    (special.betaincc, cython_special.betaincc, ('ddd',), None),
     (special.betaincinv, cython_special.betaincinv, ('ddd',), None),
+    (special.betainccinv, cython_special.betainccinv, ('ddd',), None),
     (special.betaln, cython_special.betaln, ('dd',), None),
     (special.binom, cython_special.binom, ('dd',), None),
     (special.boxcox, cython_special.boxcox, ('dd',), None),
@@ -119,7 +121,8 @@ PARAMS: List[Tuple[Callable, Callable, Tuple[str, ...], Optional[str]]] = [
      'd and l differ for negative int'),
     (special.eval_sh_jacobi, cython_special.eval_sh_jacobi, ('dddd', 'dddD', 'lddd'),
      'd and l differ for negative int'),
-    (special.eval_sh_legendre, cython_special.eval_sh_legendre, ('dd', 'dD', 'ld'), None),
+    (special.eval_sh_legendre, cython_special.eval_sh_legendre, ('dd', 'dD', 'ld'),
+     None),
     (special.exp1, cython_special.exp1, ('d', 'D'), None),
     (special.exp10, cython_special.exp10, ('d',), None),
     (special.exp2, cython_special.exp2, ('d',), None),
@@ -192,6 +195,7 @@ PARAMS: List[Tuple[Callable, Callable, Tuple[str, ...], Optional[str]]] = [
     (special.log1p, cython_special.log1p, ('d', 'D'), None),
     (special.log_expit, cython_special.log_expit, ('f', 'd', 'g'), None),
     (special.log_ndtr, cython_special.log_ndtr, ('d', 'D'), None),
+    (special.log_wright_bessel, cython_special.log_wright_bessel, ('ddd',), None),
     (special.ndtri_exp, cython_special.ndtri_exp, ('d',), None),
     (special.loggamma, cython_special.loggamma, ('D',), None),
     (special.logit, cython_special.logit, ('f', 'd', 'g'), None),
@@ -229,9 +233,11 @@ PARAMS: List[Tuple[Callable, Callable, Tuple[str, ...], Optional[str]]] = [
     (special.obl_ang1_cv, cython_special._obl_ang1_cv_pywrap, ('ddddd',), None),
     (special.obl_cv, cython_special.obl_cv, ('ddd',), None),
     (special.obl_rad1, cython_special._obl_rad1_pywrap, ('dddd',), "see gh-6211"),
-    (special.obl_rad1_cv, cython_special._obl_rad1_cv_pywrap, ('ddddd',), "see gh-6211"),
+    (special.obl_rad1_cv, cython_special._obl_rad1_cv_pywrap, ('ddddd',),
+     "see gh-6211"),
     (special.obl_rad2, cython_special._obl_rad2_pywrap, ('dddd',), "see gh-6211"),
-    (special.obl_rad2_cv, cython_special._obl_rad2_cv_pywrap, ('ddddd',), "see gh-6211"),
+    (special.obl_rad2_cv, cython_special._obl_rad2_cv_pywrap, ('ddddd',),
+     "see gh-6211"),
     (special.pbdv, cython_special._pbdv_pywrap, ('dd',), None),
     (special.pbvv, cython_special._pbvv_pywrap, ('dd',), None),
     (special.pbwa, cython_special._pbwa_pywrap, ('dd',), None),
@@ -245,19 +251,25 @@ PARAMS: List[Tuple[Callable, Callable, Tuple[str, ...], Optional[str]]] = [
     (special.pro_ang1_cv, cython_special._pro_ang1_cv_pywrap, ('ddddd',), None),
     (special.pro_cv, cython_special.pro_cv, ('ddd',), None),
     (special.pro_rad1, cython_special._pro_rad1_pywrap, ('dddd',), "see gh-6211"),
-    (special.pro_rad1_cv, cython_special._pro_rad1_cv_pywrap, ('ddddd',), "see gh-6211"),
+    (special.pro_rad1_cv, cython_special._pro_rad1_cv_pywrap, ('ddddd',),
+     "see gh-6211"),
     (special.pro_rad2, cython_special._pro_rad2_pywrap, ('dddd',), "see gh-6211"),
-    (special.pro_rad2_cv, cython_special._pro_rad2_cv_pywrap, ('ddddd',), "see gh-6211"),
+    (special.pro_rad2_cv, cython_special._pro_rad2_cv_pywrap, ('ddddd',), 
+     "see gh-6211"),
     (special.pseudo_huber, cython_special.pseudo_huber, ('dd',), None),
     (special.psi, cython_special.psi, ('d', 'D'), None),
     (special.radian, cython_special.radian, ('ddd',), None),
     (special.rel_entr, cython_special.rel_entr, ('dd',), None),
     (special.rgamma, cython_special.rgamma, ('d', 'D'), None),
     (special.round, cython_special.round, ('d',), None),
-    (special.spherical_jn, cython_special.spherical_jn, ('ld', 'ldb', 'lD', 'lDb'), None),
-    (special.spherical_yn, cython_special.spherical_yn, ('ld', 'ldb', 'lD', 'lDb'), None),
-    (special.spherical_in, cython_special.spherical_in, ('ld', 'ldb', 'lD', 'lDb'), None),
-    (special.spherical_kn, cython_special.spherical_kn, ('ld', 'ldb', 'lD', 'lDb'), None),
+    (special.spherical_jn, cython_special.spherical_jn, ('ld', 'ldb', 'lD', 'lDb'),
+     None),
+    (special.spherical_yn, cython_special.spherical_yn, ('ld', 'ldb', 'lD', 'lDb'),
+     None),
+    (special.spherical_in, cython_special.spherical_in, ('ld', 'ldb', 'lD', 'lDb'),
+     None),
+    (special.spherical_kn, cython_special.spherical_kn, ('ld', 'ldb', 'lD', 'lDb'),
+     None),
     (special.shichi, cython_special._shichi_pywrap, ('d', 'D'), None),
     (special.sici, cython_special._sici_pywrap, ('d', 'D'), None),
     (special.sindg, cython_special.sindg, ('d',), None),
@@ -308,6 +320,7 @@ def test_cython_api_completeness():
                 raise RuntimeError(f"{name} missing from tests!")
 
 
+@pytest.mark.fail_slow(5)
 @pytest.mark.parametrize("param", PARAMS, ids=IDS)
 def test_cython_api(param):
     pyfunc, cyfunc, specializations, knownfailure = param
@@ -349,4 +362,4 @@ def test_cython_api(param):
                 sup.filter(DeprecationWarning)
                 pyval = pyfunc(*pt)
                 cyval = cy_spec_func(*pt)
-            assert_allclose(cyval, pyval, err_msg="{} {} {}".format(pt, typecodes, signature))
+            assert_allclose(cyval, pyval, err_msg=f"{pt} {typecodes} {signature}")
